// 
// このコードは、https://demo.mescius.jp/diodocs/pdf のサンプルの一部として提供されています。
// © MESCIUS inc. All rights reserved.
// 
using System;
using System.IO;
using System.Drawing;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;

namespace DsPdfWeb.Demos.Basics
{
    // シンプルな３列のテキストレイアウトを作成します。
    // 少々複雑ではあるものの列のテキストを描画する上で便利な
    // 方法については、BalancedColumns を参照してください。
    public class MultiColumnText
    {
        public int CreatePDF(Stream stream)
        {
            var doc = new GcPdfDocument();
            var g = doc.NewPage().Graphics;
            var tl = g.CreateTextLayout();
            tl.DefaultFormat.FontName = "Yu Gothic";
            tl.DefaultFormat.FontSize = 10;
            tl.TextAlignment = TextAlignment.Justified;
            tl.FirstLineIndent = 72 / 2;
            tl.ParagraphSpacing = 72 / 8;
            // テキストを追加します（TextLayout は段落区切り文字として "\r\n" を解釈します）。
            tl.Append(Common.Util.getString_ja(1, 0, 20, 2, 30, true));
            // 列を設定します。
            const int colCount = 3;
            // 周囲に1/2 インチの余白
            const float margin = 72 / 2;
            // 列の間に 1/4 インチの隙間
            const float colGap = margin / 4;
            float colWidth = (doc.Pages.Last.Size.Width - margin * 2) / colCount - colGap * (colCount - 1);
            tl.MaxWidth = colWidth;
            tl.MaxHeight = doc.Pages.Last.Size.Height - margin * 2;
            // グリフを計算し、テキスト全体のレイアウトを実行します。
            tl.PerformLayout(true);
            // ループ内で、現在の列のテキストを分割して描画します。
            int col = 0;
            while (true)
            {
                // 'rest' は、収まりきらなかったテキストを受け入れます。
                var splitResult = tl.Split(null, out TextLayout rest);
                g.DrawTextLayout(tl, new PointF(margin + col * (colWidth + colGap), margin));
                if (splitResult != SplitResult.Split)
                    break;
                tl = rest;
                if (++col == colCount)
                {
                    doc.Pages.Add();
                    g = doc.Pages.Last.Graphics;
                    col = 0;
                }
            }
            // PDF ドキュメントを保存します。
            doc.Save(stream);
            return doc.Pages.Count;
        }
    }
}
